
We will mimic two screens in this challenge in order to prove tailwind and react-native-elements successfully installed. And if tailwind works, then it means nativewind successfully installed, since nativewind brings tailwind into React Native.

Firstly, mimic:
![](E2XYMwr.png)

But use tailwind and React native elements to do so.

Basically just follow the instructions at [https://www.nativewind.dev/quick-starts/expo](https://www.nativewind.dev/quick-starts/expo) which implies to have a fresh expo code. Actually you should not even use the default starter `npx create-expo APP` because it includes other code. You can try:
```
npx create-expo APP --example blank
```

FYI: More reasons why start with blank. Do not use the following because their examples are outdated and will cause conflicts preventing tailwind from working Aug 2024 including reasons such as tailwind introduced breaking changes after 3.3.2:
- DON'T: npx create-expo settings --example with-nativewind
- DON'T: npx create-expo settings --example with-react-native-elements

Then install afterwards: native wind and tailwind:
```
npm install nativewind  
npm install --save-dev tailwindcss@3.3.2
```

Make sure to init:
```
npx tailwindcss init
```

Then modify the tailwind config so it can work with react native
tailwind.config.js
```
/** @type {import('tailwindcss').Config} */  
module.exports = {  
  content: ['./App.{js,jsx,ts,tsx}', '*.{js,jsx,ts,tsx}'],  
  theme: {  
    extend: {},  
  },  
  plugins: [],  
};
```

And make sure babel.config.js:
```
module.exports = function (api) {  
  api.cache(true);  
  return {  
    presets: ['babel-preset-expo'],  
    plugins: ['nativewind/babel'],  
  };  
};
```

Start with clear cache:
```
npx expo start -c
```

Checkpoint/Troubleshooting - Staring complain
```
Web Bundling failed... AppRegistry/AppContainer.js: The argument 'path' must be a string, Uint8Array, or URL without null bytes.”  
Web Bundling failed 4233ms node_modules/expo/AppEntry.js (302 modules)  
error: shim:react-native-web/dist/exports/AppRegistry/AppContainer.js: /Users/wengffung/dev/web/mixotype/react-native/APP/shim:react-native-web/dist/exports/AppRegistry/AppContainer.js: The argument 'path' must be a string, Uint8Array, or URL without null bytes. Received '/Users/wengffung/dev/web/mixotype/react-native/APP/\x00shim:react-native-web/dist/exports/AppRegistry/AppContainer.js'
```

Two fix attempts:
1. 1. Pay attention to the path in tailwind.confg.js because it added a \x00 before shim:react-native-web, which is a null character. This is valid (note starting a path with ./** or ** is NOT valid) at tailwind.config.js
```
content: ['./App.{js,jsx,ts,tsx}', '*.{js,jsx,ts,tsx}'],
```
2. This is the worse situation if the current version hasn’t fixed this cause because it’s a hassle. Make sure your filepath does not have “vue” or “tw” or “tailwind” or “react-app”. You have to change folder name and/or change directory unfortunately.

Continuing...

Now you can use tailwind (no need to import at the js/jsx/tsx file). Notice added “bg-red-300” and others tailwind classes. Notice the NativeWindStyleSheet which allows className to work (className is disabled in React Native)

```
import { View, Text } from 'react-native';  
import { NativeWindStyleSheet } from "nativewind";  
  
NativeWindStyleSheet.setOutput({  
  default: "native",  
});  
  
export default function App() {  
  return (  
    <View className="bg-red-300 flex-1 justify-center items-center">  
      <Text>Universal React with Expo</Text>  
    </View>  
  );  
}
```
^If you don’t setup  the NativeWindStyleSheet, then className will still be enabled by NativeWind but it would only work with one class. Multiple tailwind classes in className will cause all the classes to be ignored.

Continuing...

You can add react-native-elements:
```
npm install react-native-elements
```

Then add to App.js:
```
import { Card, Header, ButtonGroup, Icon } from 'react-native-elements';
```

And:
```
    <View className="bg-red-300 flex-1 justify-center items-center">  
      <Text>Universal React with Expo</Text>  
      <Card>  
        <Card.Title>React Native Elements Test</Card.Title>  
        <Card.Divider />  
        <Text>If you see this under a divider, then React Native Elements loaded.</Text>  
      </Card>  
    </View>
```

Then you should mimic:
![](W539EOd.png)


By following this challenge, you’ve achieved the skill of adding tailwind and react native elements

---

No answer. The point is you can setup the tech. May requires more steps if newer versions changed how things work or developed conflicts. Your goal is to learn how to implement the tech in today’s times.